@@ -10,20 +10,24 @@ function (x, coefnorm = FALSE, weighting = NULL,
                   add.lc = FALSE) 
 {   
 
-  
   if (!is.null(weighting))
+
   {
     if (length(x) != length(weighting))
+
     {
       stop("Frequency and weighting differ in length", call. = FALSE)
+
     }
   }
   
   x_sort <- sort(x)   
 
+  
   i <- length(x)   
 
-  if (is.null(weighting)) { # Calculation from Doersam (2004), p. 44
+  
+  if (is.null(weighting)) { 
 
     sum_x <- sum(x_sort)
 
@@ -46,9 +50,10 @@ function (x, coefnorm = FALSE, weighting = NULL,
     }
     
     G <- 1-1/i*sum(sum_y_i)   
+
   }
   
-  else { # Calculation from Doersam (2004), p. 46-48
+  else { 
 
     n_j <- weighting
     n <- sum (n_j)
@@ -57,7 +62,7 @@ function (x, coefnorm = FALSE, weighting = NULL,
     x_j <- x_sort
     x_j_n_j <- (x_j*n_j)/sum(x_j*n_j)
     y_j <- cumsum(x_j_n_j)
-
+    
     j <- 0
     sum_y_j <- 0
     
@@ -68,9 +73,11 @@ function (x, coefnorm = FALSE, weighting = NULL,
     }
     
     G <- 1-sum(sum_y_j*n_j_n)
+
   }
   
   if (lc == TRUE) { 
+    
     lorenz (x, weighting = NULL, 
             lcx = lcx, lcy = lcy, lctitle = lctitle, le.col = le.col, lc.col = lc.col, 
             lsize = lsize, ltype = ltype, bg.col = bg.col, bgrid = bgrid, bgrid.col = bgrid.col,
@@ -80,11 +87,15 @@ function (x, coefnorm = FALSE, weighting = NULL,
   }
   
   if (coefnorm == FALSE) {   
+
     return(G)   
+
   } 
   else {
     G.norm <- (i/(i-1))*G   
+
     return (G.norm)   
+
   }
   
 }
